pub struct AllOf { /* private fields */ }Expand description
A future that resolves when all of its sub-futures have resolved.
All sub-futures must have Output = (). Completed sub-futures are dropped
eagerly so they are not polled again after returning Ready.
Resolves immediately if constructed with an empty list (vacuously true).
Prefer the all_of! macro over constructing this directly.
Implementations