pub struct ProcessHandle<T> { /* private fields */ }Expand description
Handle to a spawned process. Resolves to the process’s return value.
Dropping the handle before awaiting detaches the process — it continues to run; its return value, if any, is dropped when the process completes.
use simu::SimEnv;
let mut env = SimEnv::with_seed(0);
let h = env.handle();
env.spawn(async move {
let hc = h.clone();
let child = h.spawn(async move {
hc.timeout(3.0).await;
"charged" // the child's return value
});
let result = child.await; // suspend until the child finishes
assert_eq!(result, "charged");
assert_eq!(h.now(), 3.0);
});
env.run();Implementations