pub struct ResourceGuard { /* private fields */ }Expand description
RAII guard that holds one unit of a Resource.
The unit is released automatically when this value is dropped, waking the next suspended requester (if any) in FIFO order.